
__all__ = ['jp', 'CustomFunctions', 'JmesPathContainerMixin', 'JpDict', 'JpList', 'json_check', 'json_cast']


from functools import partial

import jmespath

from .customfunctions import *
from .jmespathtypes import *


# Define the jp convenience function
_options = jmespath.Options(custom_functions=CustomFunctions())
jp = partial(jmespath.search, options=_options)






__all__ = ['JmesPathContainerMixin', 'JpDict', 'JpList', 'json_check', 'json_cast']


import json
from functools import partial

import jmespath

from .customfunctions import CustomFunctions


_options = jmespath.Options(custom_functions=CustomFunctions())
_jpr = partial(jmespath.search, options=_options)


def json_check(obj):
    try:
        json.loads(json.dumps(obj))
    except TypeError:
        return False
    return True


def json_cast(obj):
    return json.loads(json.dumps(obj))


class JmesPathContainerMixin():

    def jp(self, expr):
        return _jpr(expr, json_cast(self))


class JpDict(JmesPathContainerMixin, dict):
    pass


class JpList(JmesPathContainerMixin, dict):
    pass




import re

from jmespath import functions


class CustomFunctions(functions.Functions):

    @functions.signature({'types': ['string']}, {'types': ['string']})
    def _func_re_search(self, s, pattern):
        return re.search(pattern, s) is not None


